@@ -1,12 +1,12 @@
 #' Data package for Lectures on Econometrics
 #'
 #' This package contains data sets for Lectures on Econometrics by Chirok Han
-#' @docType data
+#' @docType package
 #' @name loedata
-#' @author \packageAuthor{loedata}
 #' @aliases loedata loedata-package
 #' @seealso \code{help(package="loedata")}
-NULL
+#' @keywords internal
+"_PACKAGE"
 
 #' Boyle data set
 #'
@@ -19,7 +19,6 @@ NULL
 #'   \item{pressure}{the pressure sustained by the included air}
 #' }
 #' @usage data(Boyle)
-#' @author \packageAuthor{loedata}
 "Boyle"
 
 #' CO2 emissions
@@ -31,11 +30,10 @@ NULL
 #' \describe{
 #'   \item{ccode}{country code}
 #'   \item{cname}{country name}
-#'   \item{gdppcppp}{GDP per capital, ppp adjusted (USD)}
+#'   \item{gdppcppp}{GDP per capita, ppp adjusted (USD)}
 #'   \item{co2pc}{CO2 emissions per capita (ton)}
 #' }
 #' @usage data(Ekc)
-#' @author \packageAuthor{loedata}
 "Ekc"
 
 #' Death rate and related variables for Korean districts
@@ -56,7 +54,6 @@ NULL
 #'   \item{deathrate}{= death/regpop*1000}
 #' }
 #' @usage data(Death)
-#' @author \packageAuthor{loedata}
 "Death"
 
 #' Card and Krueger (1994) fastfood data set
@@ -84,7 +81,7 @@ NULL
 #'   \item{empft}{# full-time employees}
 #'   \item{emppt}{# part-time employees}
 #'   \item{nmgrs}{# managers/assistant managers}
-#'   \item{fte}{full time equivalent, FTE = empft + nmgrs + 0-.5*emppt [+]}
+#'   \item{fte}{full time equivalent, FTE = empft + nmgrs + 0.5*emppt [+]}
 #'   \item{dfte}{FTE for after - FTE for before [+]}
 #'   \item{wage_st}{starting wage ($/hr)}
 #'   \item{inctime}{months to usual first raise}
@@ -105,7 +102,6 @@ NULL
 #' @details See \code{attr(Fastfood, "desc")}. [+] are added by Chirok Han.
 #' @references
 #' Card, D., and A. Krueger (1994). Minimum Wages and Employment: A Case Study of the Fast Food Industry in New Jersey and Pennsylvania, American Economic Review 84, 772-793.
-#' @author \packageAuthor{loedata}
 "Fastfood"
 
 #' Open DART firm data
@@ -140,7 +136,6 @@ NULL
 #'   \item{netinc}{net income in KRW}
 #' }
 #' @usage data(Firmdata)
-#' @author \packageAuthor{loedata}
 "Firmdata"
 
 #' Galton family data
@@ -153,7 +148,7 @@ NULL
 #'   \item{id}{parent ID, a factor with levels \code{001}-\code{204}}
 #'   \item{father}{height of father}
 #'   \item{mother}{height of mother}
-#'   \item{midparht}{mid-parent height, calculated as \code{father + 1.08*mother)/2}}
+#'   \item{midparht}{mid-parent height, calculated as \code{(father + 1.08*mother)/2}}
 #'   \item{numchild}{number of children}
 #'   \item{numson}{number of sons}
 #'   \item{numdtr}{number of daughters}
@@ -163,7 +158,6 @@ NULL
 #' }
 #' @usage data(Galtonpar)
 #' @seealso \code{HistData::GaltonFamilies}
-#' @author \packageAuthor{loedata}
 "Galtonpar"
 
 #' Household consumption shares
@@ -179,7 +173,6 @@ NULL
 #' }
 #' @usage data(Hcons)
 #' @seealso \code{\link{Hies}}
-#' @author \packageAuthor{loedata}
 "Hcons"
 
 #' Household Income and Expenditure Survey 2016
@@ -218,7 +211,6 @@ NULL
 #' }
 #' @usage data(Hies)
 #' @seealso \code{\link{Hcons}}
-#' @author \packageAuthor{loedata}
 "Hies"
 
 #' The Boston HMDA data set
@@ -230,7 +222,7 @@ NULL
 #' \describe{
 #'   \item{dir}{debt payments to total income ratio}
 #'   \item{hir}{housing expenses to income ratio}
-#'   \item{lvr}{ratio of size of loan to assessed value of propensity}
+#'   \item{lvr}{ratio of size of loan to assessed value of property}
 #'   \item{ccs}{consumer credit score from 1 to 6 (a low value being a good score)}
 #'   \item{mcs}{mortgage credit score from 1 to 4 (a low value being a good score)}
 #'   \item{pbcr}{1 if public bad credit score}
@@ -243,7 +235,7 @@ NULL
 #'   \item{deny}{1 if mortgage application denied}
 #' }
 #' @usage data(Hmda)
-#' @author \packageAuthor{loedata}
+#' @seealso \code{Ecdat::Hmda}
 "Hmda"
 
 #' Artificial data for studying IV estimation
@@ -259,14 +251,13 @@ NULL
 #'   \item{z2b}{z2b variable}
 #' }
 #' @usage data(Ivdata)
-#' @author \packageAuthor{loedata}
 "Ivdata"
 
 #' Subset of 2011 KLIPS
 #'
 #' Subset (30 <= age <= 39, nonzero income, 9 <= educ < 20) of 2011 KLIPS
 #'
-#' @source Korea Labor Institute \url{https://www.kli.re.kr/klips/index.do}
+#' @source Korea Labor Institute \url{https://www.kli.re.kr/klips}
 #' @format A data frame with 646 rows of 8 variables:
 #' \describe{
 #'   \item{age}{age}
@@ -279,14 +270,13 @@ NULL
 #'   \item{married}{1 if married}
 #' }
 #' @usage data(Klips)
-#' @author \packageAuthor{loedata}
 "Klips"
 
 #' KLoSA wave 4
 #'
 #' Korea Longitudinal Study of Aging wave 4 (2012)
 #'
-#' @source \url{https://survey.keis.or.kr/klosa/klosa01.jsp}
+#' @source \url{https://survey.keis.or.kr/klosa/klosa04.jsp}
 #' @format A data frame with 2153 rows of 45 variables:
 #' \describe{
 #'   \item{pid}{personal ID}
@@ -338,7 +328,6 @@ NULL
 #'   \item{voluntary}{hours of volunteer service}
 #' }
 #' @usage data(Klosa)
-#' @author Goeun Lee, \packageAuthor{loedata}
 "Klosa"
 
 #' Average salary
@@ -360,7 +349,6 @@ NULL
 #'   \item{kosdaq}{=1 if KOSDAQ}
 #' }
 #' @usage data(Ksalary)
-#' @author \packageAuthor{loedata}
 "Ksalary"
 
 #' Public servants and financial independence
@@ -375,7 +363,6 @@ NULL
 #'   \item{finind}{financial independence index, = (local tax + other income)/budget * 100}
 #' }
 #' @usage data(Pubserv)
-#' @author \packageAuthor{loedata}
 "Pubserv"
 
 #' Korean regional data (2014-2016 averages)
@@ -390,7 +377,7 @@ NULL
 #'   \item{region}{Region name}
 #'   \item{type}{1=si (non-metropolitan cities), 2=gun, 3=gu in metro cities and provinces}
 #'   \item{grdp}{gross regional GDP}
-#'   \item{regpop}{population}
+#'   \item{regpop}{registered population (end of year, by registration record, excl. foreigners)}
 #'   \item{popgrowth}{population growth}
 #'   \item{eq5d}{the EQ-5D health index}
 #'   \item{deaths}{number of registered deaths}
@@ -405,12 +392,15 @@ NULL
 #'   \item{accpv}{# of accidents per 1000 vehicles}
 #'   \item{dumppc}{waste dump per person, kg/day}
 #'   \item{stratio}{# of students per teacher}
-#'   \item{deathrate}{# of deaths per 100,000 pop}
-#'   \item{pctmale}{=gcmp/(gcomp+100)*100, \% of male}
+#'   \item{deathrate}{# of deaths per 100,000 mid-year population (note: not equal to deaths/regpop*1e5)}
+#'   \item{nbirth}{# of births}
+#'   \item{cbrate}{Crude birth rate (per 1,000 pop)}
+#'   \item{tfrate}{Total fertility rate}
+#'   \item{pctmale}{=gcomp/(gcomp+100)*100, \% of male}
 #'   \item{accpc}{=vehipc*accpv, # of accidents per 1000 pop}
 #' }
 #' @usage data(Regko)
-#' @author \packageAuthor{loedata}
+#' @seealso \code{RegkoPanel}
 "Regko"
 
 #' Korean regional panel data (2014-2016)
@@ -426,7 +416,7 @@ NULL
 #'   \item{type}{1=si (non-metropolitan cities), 2=gun, 3=gu in metro cities and provinces}
 #'   \item{year}{Year}
 #'   \item{grdp}{gross regional GDP}
-#'   \item{regpop}{population}
+#'   \item{regpop}{registered population (end of year, by registration record, excl. foreigners)}
 #'   \item{popgrowth}{population growth (=100*(regpop/regpop[-1]-1))}
 #'   \item{eq5d}{the EQ-5D health index}
 #'   \item{deaths}{number of deaths}
@@ -436,15 +426,18 @@ NULL
 #'   \item{aged}{\% of aged 65 and over}
 #'   \item{divorce}{# of divorces per 1000 pop}
 #'   \item{medrate}{# of medical beds per 1000 pop}
-#'   \item{gcomp}{gender composition # men / 100 women}
+#'   \item{gcomp}{gender composition # men per 100 women}
 #'   \item{vehipc}{# of vehicles per person}
 #'   \item{accpv}{# of accidents per 1000 vehicles}
 #'   \item{dumppc}{waste dump per person, kg/day}
 #'   \item{stratio}{# of students per teacher}
-#'   \item{deathrate}{# of deaths per 100,000 pop}
-#'   \item{pctmale}{=gcmp/(gcomp+100)*100, \% of male}
+#'   \item{deathrate}{# of deaths per 100,000 mid-year population (not equal to deaths/regpop*1e5)}
+#'   \item{nbirth}{# of births}
+#'   \item{cbrate}{Crude birth rate (per 1,000 pop)}
+#'   \item{tfrate}{Total fertility rate}
+#'   \item{pctmale}{=gcomp/(gcomp+100)*100, \% of male}
 #'   \item{accpc}{=vehipc*accpv, # of accidents per 1000 pop}
 #' }
 #' @usage data(RegkoPanel)
-#' @author \packageAuthor{loedata}
+#' @seealso \code{Regko}
 "RegkoPanel"
